@@ -8,12 +8,12 @@
 #include <pika/command_line_handling/get_env_var_as.hpp>
 #include <pika/debugging/print.hpp>
 #include <pika/execution.hpp>
-#include <pika/future.hpp>
 #include <pika/init.hpp>
 #include <pika/mpi.hpp>
 #include <pika/program_options.hpp>
 #include <pika/synchronization/counting_semaphore.hpp>
 #include <pika/testing.hpp>
+#include <pika/thread.hpp>
 //
 #include <boost/lockfree/stack.hpp>
 #include <fmt/format.h>
@@ -22,6 +22,7 @@
 #include <array>
 #include <atomic>
 #include <cstdint>
+#include <cstdlib>
 #include <iomanip>
 #include <iostream>
 #include <memory>
@@ -450,7 +451,9 @@ int pika_main(pika::program_options::variables_map& vm)
         }
         // let the user polling go out of scope
     }
-    return pika::finalize();
+
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 //----------------------------------------------------------------------------
