@@ -104,8 +104,7 @@ namespace pika::execution {
 
         void default_agent::yield_k(std::size_t k, char const* /* desc */)
         {
-            if (k < 4) {}
-            else if (k < 16) { PIKA_SMT_PAUSE; }
+            if (k < 16) { PIKA_SMT_PAUSE; }
             else if (k < 32 || k & 1)
             {
 #if defined(PIKA_WINDOWS)
@@ -135,8 +134,7 @@ namespace pika::execution {
 
         void default_agent::spin_k(std::size_t k, char const* /* desc */)
         {
-            if (k < 4) {}
-            else { PIKA_SMT_PAUSE; }
+            for (std::size_t i = 0; i < k; ++i) { PIKA_SMT_PAUSE; }
         }
 
         void default_agent::suspend(char const* /* desc */)
@@ -147,7 +145,7 @@ namespace pika::execution {
             running_ = false;
             resume_cv_.notify_all();
 
-            while (!running_) { suspend_cv_.wait(l); }
+            suspend_cv_.wait(l, [&] { return running_; });
 
             if (aborted_)
             {
@@ -158,22 +156,18 @@ namespace pika::execution {
 
         void default_agent::resume(char const* /* desc */)
         {
-            {
-                std::unique_lock<std::mutex> l(mtx_);
-                while (running_) { resume_cv_.wait(l); }
-                running_ = true;
-            }
+            std::unique_lock<std::mutex> l(mtx_);
+            resume_cv_.wait(l, [&] { return !running_; });
+            running_ = true;
             suspend_cv_.notify_one();
         }
 
         void default_agent::abort(char const* /* desc */)
         {
-            {
-                std::unique_lock<std::mutex> l(mtx_);
-                while (running_) { resume_cv_.wait(l); }
-                running_ = true;
-                aborted_ = true;
-            }
+            std::unique_lock<std::mutex> l(mtx_);
+            resume_cv_.wait(l, [&] { return !running_; });
+            running_ = true;
+            aborted_ = true;
             suspend_cv_.notify_one();
         }
 
