@@ -10,6 +10,7 @@
 #include <pika/testing.hpp>
 
 #include <cstddef>
+#include <cstdlib>
 #include <string>
 #include <thread>
 #include <vector>
@@ -50,7 +51,8 @@ int pika_main()
     });
     t.join();
 
-    return pika::finalize();
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
